@@ -1,6 +1,5 @@
 from setuptools import Extension
 from setuptools.command.build_py import build_py as build_py_orig
-from setuptools.command.install import install as _install
 import shutil
 
 from Cython.Build import cythonize
@@ -24,21 +23,13 @@ class build_py(build_py_orig):
         pass
 
 
-def get_install(setup_py):
-    class install(_install):
-        def run(self):
-            _install.run(self)
-            # Do something magical
-            if os.environ.get('NO_CLEAR_ARTIPY') == "1":
-                return
-            else:
-                dirname = os.path.split(setup_py)[0]
-                shutil.rmtree(os.path.join(dirname, "build"))
-                for root, subdirs, files in os.walk(dirname):
-                    for fname in os.listdir(root):
-                        fname.endswith('.c')
-                        os.remove(fname)
-    return install
+def clean(setup_py):
+    dirname = os.path.split(setup_py)[0]
+    shutil.rmtree(os.path.join(dirname, "build"))
+    for root, subdirs, files in os.walk(dirname):
+        for fname in os.listdir(root):
+            fname.endswith('.c')
+            os.remove(fname)
 
 
 def artipy(dirname, setup_py):
@@ -47,5 +38,5 @@ def artipy(dirname, setup_py):
     else:
         return {
             'ext_modules': cythonize(find_extensions(dirname, setup_py)),
-            'cmdclass': {'build_py': build_py, 'install': get_install(setup_py)},
+            'cmdclass': {'build_py': build_py},
         }
